==> pymmcore-10.1.1.70.6.tar.gz: pymmcore-10.1.1.70.6/mmCoreAndDevices/MMCore/Devices/StateInstance.h <==
// PROJECT:       Micro-Manager
// SUBSYSTEM:     MMCore
//
// COPYRIGHT:     University of California, San Francisco, 2014,
//                All Rights reserved
//
// LICENSE:       This file is distributed under the "Lesser GPL" (LGPL) license.
//                License text is included with the source distribution.
//
//                This file is distributed in the hope that it will be useful,
//                but WITHOUT ANY WARRANTY; without even the implied warranty
//                of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
//                IN NO EVENT SHALL THE COPYRIGHT OWNER OR
//                CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
//                INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES.
//
// AUTHOR:        Mark Tsuchida

#pragma once

#include "DeviceInstanceBase.h"


class StateInstance : public DeviceInstanceBase<MM::State>
{
public:
   StateInstance(CMMCore* core,
         boost::shared_ptr<LoadedDeviceAdapter> adapter,
         const std::string& name,
         MM::Device* pDevice,
         DeleteDeviceFunction deleteFunction,
         const std::string& label,
         mm::logging::Logger deviceLogger,
         mm::logging::Logger coreLogger) :
      DeviceInstanceBase<MM::State>(core, adapter, name, pDevice, deleteFunction, label, deviceLogger, coreLogger)
   {}

   int SetPosition(long pos);
   int SetPosition(const char* label);
   int GetPosition(long& pos) const;
   std::string GetPositionLabel() const; // Name differs from MM::Device
   std::string GetPositionLabel(long pos) const;
   int GetLabelPosition(const char* label, long& pos) const;
   int SetPositionLabel(long pos, const char* label);
   unsigned long GetNumberOfPositions() const;
   int SetGateOpen(bool open = true);
   int GetGateOpen(bool& open);
};

==> pymmcore-11.5.1.73.0.tar.gz: pymmcore-11.5.1.73.0/mmCoreAndDevices/MMCore/Devices/StateInstance.h <==
// PROJECT:       Micro-Manager
// SUBSYSTEM:     MMCore
//
// COPYRIGHT:     University of California, San Francisco, 2014,
//                All Rights reserved
//
// LICENSE:       This file is distributed under the "Lesser GPL" (LGPL) license.
//                License text is included with the source distribution.
//
//                This file is distributed in the hope that it will be useful,
//                but WITHOUT ANY WARRANTY; without even the implied warranty
//                of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
//                IN NO EVENT SHALL THE COPYRIGHT OWNER OR
//                CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
//                INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES.
//
// AUTHOR:        Mark Tsuchida

#pragma once

#include "DeviceInstanceBase.h"


class StateInstance : public DeviceInstanceBase<MM::State>
{
public:
   StateInstance(CMMCore* core,
         std::shared_ptr<LoadedDeviceAdapter> adapter,
         const std::string& name,
         MM::Device* pDevice,
         DeleteDeviceFunction deleteFunction,
         const std::string& label,
         mm::logging::Logger deviceLogger,
         mm::logging::Logger coreLogger) :
      DeviceInstanceBase<MM::State>(core, adapter, name, pDevice, deleteFunction, label, deviceLogger, coreLogger)
   {}

   int SetPosition(long pos);
   int SetPosition(const char* label);
   int GetPosition(long& pos) const;
   std::string GetPositionLabel() const; // Name differs from MM::Device
   std::string GetPositionLabel(long pos) const;
   int GetLabelPosition(const char* label, long& pos) const;
   int SetPositionLabel(long pos, const char* label);
   unsigned long GetNumberOfPositions() const;
   int SetGateOpen(bool open = true);
   int GetGateOpen(bool& open);
};
